=============
``salt-call``
=============

Synopsis
========

.. code-block:: bash

    salt-call [options]

Description
===========

The salt-call command is used to run module functions locally on a minion 
instead of executing them from the master.

Options
=======

.. program:: salt-call

.. include:: _includes/common-options.rst

.. option:: -g, --grains

    Return the information generated by the Salt grains

.. option:: -m MODULE_DIRS, --module-dirs=MODULE_DIRS

    Specify an additional directories to pull modules from, multiple
    directories can be delimited by commas

.. option:: -d, --doc, --documentation

    Return the documentation for the specified module or for all modules if
    none are specified

.. option:: --master=MASTER

    Specify the master to use. The minion must be authenticated with the 
    master. If this option is omitted, the master options from the minion 
    config will be used. If multi masters are set up the first listed master 
    that responds will be used.

.. option:: --return RETURNER

    Set salt-call to pass the return data to one or many returner interfaces.
    To use many returner interfaces specify a comma delimited list of
    returners.

.. option:: --local

    Run salt-call locally, as if there was no master running.

.. include:: _includes/logging-options.rst
.. |logfile| replace:: /var/log/salt/minion
.. |loglevel| replace:: ``info``

.. include:: _includes/output-options.rst


See also
========

:manpage:`salt(1)`
:manpage:`salt-master(1)`
:manpage:`salt-minion(1)`
